
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

##############################
Sample usage for gluesemantics
##############################

.. include:: ../../nltk/test/gluesemantics.doctest